#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 microlens-mtl
version:              0.2.0.1
visibility:           public
id:                   microlens-mtl-0.2.0.1-C8zdU46BWsFKgoqVqJruhT
key:                  microlens-mtl-0.2.0.1-C8zdU46BWsFKgoqVqJruhT
license:              BSD-3-Clause
maintainer:           Monadfix <hi@monadfix.io>
author:               Edward Kmett, Artyom Kazak
homepage:             http://github.com/monadfix/microlens
synopsis:             microlens support for Reader/Writer/State from mtl
description:
    This package contains functions (like '\''view'\'' or '\''+='\'') which work on '\''MonadReader'\'', '\''MonadWriter'\'', and '\''MonadState'\'' from the mtl package.

    This package is a part of the <http://hackage.haskell.org/package/microlens microlens> family; see the readme <https://github.com/monadfix/microlens#readme on Github>.

category:             Data, Lenses
abi:                  f68047017b22b090c1287901700aeeaf
exposed:              True
exposed-modules:      Lens.Micro.Mtl Lens.Micro.Mtl.Internal
import-dirs:          /usr/lib/ghc-8.10.5/site-local/microlens-mtl-0.2.0.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/microlens-mtl-0.2.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/microlens-mtl-0.2.0.1
hs-libraries:         HSmicrolens-mtl-0.2.0.1-C8zdU46BWsFKgoqVqJruhT
depends:
    base-4.14.2.0 microlens-0.4.12.0-7mbtYeVEJj9DE2AV66WaoK mtl-2.2.2
    transformers-0.5.6.2 transformers-compat-0.7-DEkprM8uNQhJDKKPf6L2ns

haddock-interfaces:
    /usr/share/doc/haskell-microlens-mtl/html/microlens-mtl.haddock

haddock-html:         /usr/share/doc/haskell-microlens-mtl/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

